/******************************************************************************

Exp2CompRateAnalysis.do

This file performs additional analysis on the completion rate of the 
part-2 survey in experiment 2.

*******************************************************************************/

use "$preppeddata/Experiment 2/CompletionData.dta", clear

** Get average reminder effect for the low and high groups
reg completed reminder if high_bonus == 0
local lowincentremindereffect: di %3.0f _b[reminder] * 100
latex_write \lowincentremindereffect "`lowincentremindereffect'"
local lowincenteffectdec: di %3.2f _b[reminder]
latex_write \lowincenteffectdec "`lowincenteffectdec'"

reg completed reminder if high_bonus == 1
local highincentremindereffect: di %3.0f _b[reminder] * 100
latex_write \highincentremindereffect "`highincentremindereffect'"
local highincenteffectdec: di %3.2f _b[reminder]
latex_write \highincenteffectdec "`highincenteffectdec'"

** Get max and min effects 
preserve

** Get combinations of delay and reward
egen delayreward = group(delay high_bonus)

** Get reminder effect for each group
gen remindereffect = .
gen remindereffectse = .

foreach i of numlist 1/8 {
	reg completed reminder if delayreward == `i'
	replace remindereffect = _b[reminder] if delayreward == `i'
	replace remindereffectse = _se[reminder] if delayreward == `i'
}

** Get one row per group
duplicates drop delayreward, force

** Get min and max
sum remindereffect

** Take effect — write to latex
local minremindereffect: di %3.0f r(min) * 100
local maxremindereffect: di %3.0f r(max) * 100
latex_write \minremindereffect "`minremindereffect'"
latex_write \maxremindereffect "`maxremindereffect'"

** Get SEs for those values
gen mineffectse = cond(remindereffect == r(min), remindereffectse, .)
gen maxeffectse = cond(remindereffect == r(max), remindereffectse, .)
collapse (sum) mineffectse maxeffectse

local mineffectse: di %9.2f mineffectse * 100
local maxeffectse: di %9.2f maxeffectse * 100

latex_write \mineffectse "`mineffectse'"
latex_write \maxeffectse "`maxeffectse'"

restore

** Creating var labels 

	label variable bonus2 "Incentive (\\$)"
	label variable delay "Delay (Days)"
	label variable reminder "Received Reminder"
	
	label define delays_day 2 "2 Day Delay" 7 "1 Week Delay" ///
		21 "3 Week Delay" 42 "6 Week Delay", modify
	label values delay delays_day
	
	gen logdelay = log(delay)
	label variable logdelay "Log(Delay)"
			

** Spike plot

** Add spike groups
** 1 = Low, No Reminder; 2 = Low, Reminder
** 3 = High, No Reminder; 3 = High, Reminder
preserve

gen incentive_reminder = 1 if inlist(bonus2, 3, 4) & reminder == 0
replace incentive_reminder = 2 if inlist(bonus2, 3, 4) & reminder == 1
replace incentive_reminder = 3 if inlist(bonus2, 11, 12) & reminder == 0
replace incentive_reminder = 4 if inlist(bonus2, 11, 12) & reminder == 1

** Spike plot of mean WTPs by delay & incentive

	local varname completed
	local group1 delay
	local group2 incentive_reminder
	collapse (mean) y = `varname' (semean) se_y = `varname', by(`group1' `group2')

	sort `group1' `group2'
	gen x = _n
	replace x = _n + 2 if _n >= 5
	replace x = _n + 4 if _n >= 9
	replace x = _n + 6 if _n >= 13

	gen yu = y + 1.96*se_y
	gen yl = y - 1.96*se_y

	separate y, by(`group2')
	separate yu, by(`group2')
	separate yl, by(`group2')

	twoway (scatter y1 x, msymbol(circle) color(edkblue)) ///
		   (rspike yu1 yl1 x, color(edkblue))  ///
		   (scatter y2 x , msymbol(square) color(dknavy)) ///
		   (rspike yu2 yl2 x, color(dknavy) )  ///
		   (scatter y3 x , msymbol(triangle) color(cranberry)) ///
		   (rspike yu3 yl3 x, color(cranberry))  ///
		   (scatter y4 x , msymbol(X) color(maroon)) ///
		   (rspike yu4 yl4 x, color(maroon)), scheme(s1color) ///
		   xlabel(none) xtitle(" ") b2("Part-2 Delay") /// 
		   ytitle("Completion Rate") yline(0, lpattern(dash) lcolor(black)) ///
		   xline(5.5,  lwidth(thin) lcolor(dimgray)) ///
		   xline(11.5,  lwidth(thin) lcolor(dimgray)) ///
		   xline(17.5,  lwidth(thin) lcolor(dimgray)) ///
		   text(-0.05 1.4 "2 Day", place(e)) ///
		   text(-0.05 6.95 "1 Week", place(e)) ///
		   text(-0.05 12.4 "3 Weeks", place(e)) ///
		   text(-0.05 18.2 "6 Weeks", place(e)) ///
		   legend(order(1 "Low Incentive" "No Reminder" 3 "Low Incentive" "Reminder" ///
		   5 "High Incentive" "No Reminder" 7 "High Incentive" "Reminder") position(3) bplacement(neast) ///
		   region(lstyle(none)) row(4) size(small)) ylabel(0(0.25)1) xsc(r(0 23))
		   
	graph export "$figures/Experiment 2/SpikePlot_CompletionRates.pdf", replace
	
restore

gen ptestimate = .
gen stderror = .
foreach bonustype in 0 1 {
	foreach delaytype in 2 7 21 42 {
		reg completed reminder if high_bonus == `bonustype' ///
		& delay == `delaytype'
		replace ptestimate = r(table)[1,1] if high_bonus == `bonustype' & delay == `delaytype'
		replace stderror = r(table)[2,1] if high_bonus == `bonustype' & delay == `delaytype'
		}
}
	
keep delay high_bonus ptestimate stderror
duplicates drop delay high_bonus, force

gen x = _n

gen yu = ptestimate + 1.96*stderror
gen yl = ptestimate - 1.96*stderror

** Add spike groups
** 1 = Low, 2-Day Delay; 2 = Low, 1-Week Delay
** 3 = High, 2-Day Delay; 3 = High, 1-Week Delay

gen bonus_delay = 1 if high_bonus == 0 & delay == 2
replace bonus_delay = 2 if high_bonus == 1 & delay == 2
replace bonus_delay = 3 if high_bonus == 0 & delay == 7
replace bonus_delay = 4 if high_bonus == 1 & delay == 7
replace bonus_delay = 5 if high_bonus == 0 & delay == 21
replace bonus_delay = 6 if high_bonus == 1 & delay == 21
replace bonus_delay = 7 if high_bonus == 0 & delay == 42
replace bonus_delay = 8 if high_bonus == 1 & delay == 42

separate ptestimate, by(bonus_delay)
separate yu, by(bonus_delay)
separate yl, by(bonus_delay)

drop ptestimate stderror yu yl

twoway (scatter ptestimate1 bonus_delay, msymbol(square) color(dknavy)) ///
		   (rspike yu1 yl1 bonus_delay, color(dknavy))  ///
		   (scatter ptestimate2 bonus_delay, msymbol(X) color(maroon)) ///
		   (rspike yu2 yl2 bonus_delay, color(maroon))  ///
		   (scatter ptestimate3 bonus_delay, msymbol(square) color(dknavy)) ///
		   (rspike yu3 yl3 bonus_delay, color(dknavy))  ///
		   (scatter ptestimate4 bonus_delay, msymbol(X) color(maroon)) ///
		   (rspike yu4 yl4 bonus_delay, color(maroon)) ///
		   (scatter ptestimate5 bonus_delay, msymbol(square) color(dknavy)) ///
		   (rspike yu5 yl5 bonus_delay, color(dknavy)) ///
		   (scatter ptestimate6 bonus_delay, msymbol(X) color(maroon)) ///
		   (rspike yu6 yl6 bonus_delay, color(maroon)) ///
		   (scatter ptestimate7 bonus_delay, msymbol(square) color(dknavy)) ///
		   (rspike yu7 yl7 bonus_delay, color(dknavy))  ///
		   (scatter ptestimate8 bonus_delay, msymbol(X) color(maroon)) ///
		   (rspike yu8 yl8 bonus_delay, color(maroon)), scheme(s1color) ///
		   xlabel(none) xtitle(" ") b2("Part-2 Delay") /// 
		   ytitle("Reminder Effect") yline(0, lpattern(dash) lcolor(black)) ///
		   xline(2.5,  lwidth(thin) lcolor(dimgray)) ///
		   xline(4.5,  lwidth(thin) lcolor(dimgray)) ///
		   xline(6.5,  lwidth(thin) lcolor(dimgray)) ///
		   text(-0.25 1.4 "2 Day", place(e)) ///
		   text(-0.25 3 "1 Week", place(e)) ///
		   text(-0.25 4.9 "3 Weeks", place(e)) ///
		   text(-0.25 6.7 "6 Weeks", place(e)) ///
		   legend(order(1 "Low Incentive" 7 "High Incentive") ///
		   position(3) bplacement(neast) ///
		   region(lstyle(none)) row(4) size(small))

graph export "$figures/Experiment 2/SpikePlot_ReminderTreatmentEffect.pdf", replace
		   
		   
