/******************************************************************************

Exp2RiskAversion.do

This file creates a measure of risk aversion in the part-2 survey of
experiment 2, interacts this measure with other covariates to analyze the effect
on WTP in experiment 2, and creates a table that reports the results.

*******************************************************************************/

** Load data
use "$rawdata/Experiment 2/Part 2 Data.dta", clear

** Get string variables 
qui ds *, has(type string)
local varlist `r(varlist)'

** Start counter variable 
local counter 1

** Get cash variables with no endowment
foreach var of local varlist {
	if "`var'" != "mturkid" {
		count if (strpos(`var', "for sure")| strpos(`var', "50% chance of $")) ///
			& !strpos(`var', "lottery tickets")
			
		if r(N) > 0 {
			** Change to 1 if they chose the risky option
			gen q`counter' = (strpos(`var', "for sure") == 0)
			local tokeep `tokeep' q`counter'
			local counter = `counter' + 1
		}
		
		* Drop variables now that we've converted the cash variables with no endowment
		drop `var'
	}
}

** Keep relevant variables
keep mturkid `tokeep'

** Create a variable that stores number of "certain" choices
egen risky_n = rowtotal(q*)

** Get median
sum risky_n, detail

** Create indicator variable
gen risky = (risky_n > r(p50))
gen risky_frac = risky_n / 10

** Change data type of mturkid
recast str20 mturkid
keep mturkid risky risky_frac

** Merge with WTP data
merge 1:m mturkid using "$preppeddata/Experiment 2/wtp_pooled_exp2.dta"

** Drop people who saw more than 1 screen during part 1 
** (i.e. people who show up in part 2 data, but not part 1)
drop if _merge == 1

drop _merge

** Only keep people who weren't top or bottom coded
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop _merge
keep if no_top_bottom_coding == 1

** Rename incentive 
rename payment incentive
	
** Gen high bonus
gen high_bonus = (max_bonus == 12)

** Add labels
label variable high_bonus "High Incentive"
label variable incentive "Extra \\$1"
label variable risky "Above Median Risky Choice Total"
label variable risky "Above Median Risky Choice Total"
label variable risky_frac "Fraction of Risky Choices"

replace incentive = (incentive == 4 | incentive == 12)

** Add num participants
count 
local num_participants = `r(N)' / 16

reg WTP c.risky c.incentive c.high_bonus  c.risky#c.incentive c.risky#c.high_bonus ///
	c.incentive#c.high_bonus c.risky#c.incentive#c.high_bonus, vce(cluster mturkid) baselevels
eststo riskaversionWTP
estadd local n_participants `e(N_clust)'

reg WTP c.risky_frac c.incentive c.high_bonus  c.risky_frac#c.incentive c.risky_frac#c.high_bonus ///
	c.incentive#c.high_bonus c.risky_frac#c.incentive#c.high_bonus, vce(cluster mturkid) baselevels
eststo riskaversionWTPfrac
estadd local n_participants `e(N_clust)'

merge m:1 mturkid using "$preppeddata/Experiment 2/CompletionData.dta", keepusing(completed)
label variable completed "Completed Part-2 Survey"

reg WTP c.completed c.incentive c.high_bonus  c.completed#c.incentive c.completed#c.high_bonus ///
	c.incentive#c.high_bonus c.completed#c.incentive#c.high_bonus, vce(cluster mturkid) baselevels
eststo completedWTPfrac
estadd local n_participants `e(N_clust)'

esttab riskaversionWTP riskaversionWTPfrac completedWTPfrac using `"$tables/Experiment 2/riskaversion_WTP.tex"', ///
	replace se booktabs nonote nobaselevels numbers b(%8.2f) se(%8.3f)  ///
	star(* 0.10 ** 0.05 *** 0.01) label ///
	mgroups("WTP for Reminders (\\$)", pattern(1 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
	mtitles("" "" "") eqlabels("" "" "") ///
	stats(N n_participants, ///
	l("Observations" "Number of Participants") ///
	fmt(%9.0fc %9.0fc))
