/******************************************************************************

Exp3SampleRestriction.do

This file runs regressions on the data from the Experiment 3 launch of 
the Pay to Plan project under the following sample restrictions: 

#1 Eliminate people who in at least one block always want easy version at $2, or always want hard version at $4.
#2 Eliminate people who ever decrease their WTP for the easy version when incentives increase by $1.
#3 Eliminate people who decrease their WTP with higher incentives two or more times.

*******************************************************************************/

** Import data
local source "launch"
use `"$preppeddata/Experiment 3/wtp_allparticipants.dta"', clear

** Keep relevant variables — xnorm variables are about choices 
keep prolific_id xnorm_?payment xnorm_?choicefinal

destring xnorm_?payment, replace

** Reshape from wide to long
reshape long xnorm_@payment xnorm_@choicefinal, ///
 i(prolific_id) j(counter)
 
drop if counter == 0

** Rename for clarity
rename xnorm_choicefinal choice
rename xnorm_payment payment

gen block = 1 if counter == 1 | counter == 2 | counter == 3
replace block = 2 if counter == 4 | counter == 5 | counter == 6

** Create choicenum
destring choice, gen(choicenum) i("left" "right")

** Convert choices to terms of left
replace choicenum = choicenum - 1 if strpos(choice, "right")

** Convert string choice
replace choice = string(choicenum) + "left"

** Add number of times 1 left was chosen
gen strategy_1left = (choice == "1left")
egen times_1left = total(strategy_1left), by(prolific_id)
drop strategy_1left

** Add increments & max bonus of MPL by incentive
gen increment = 0.25
gen max_bonus = 4

** Calculate WTP (WTP is equated with the midpoint of the crossover interval.) 
gen WTP = ((max_bonus - (choicenum -1) * increment) + ///
(max_bonus - (choicenum *increment))) / 2 if choicenum >= 17

replace WTP = -((max_bonus - (32 - choicenum) * increment) ///
+ (max_bonus - (33 - choicenum) * increment)) / 2 if choicenum < 17

** Create indicators for each of the three sample restrictions listed above
** #1 ever_extreme, #2 ever_decrease, #3 decrease2ormore

** #1 Eliminate people who in at least one block want easy at $2 or hard at $4
tempvar extreme
gen `extreme' = (payment == 2 & WTP == 4.125) | (payment == 4 & WTP == -4.125)
egen extreme_total = total(`extreme'), by(prolific_id)

** Gen variable if at least one decision matches that condition
gen ever_extreme = (extreme_total > 0)

** Add by block too
** Block 1
tempvar block1extreme
gen `block1extreme' = ((payment == 2 & WTP == 4.125) | (payment == 4 & WTP == -4.125)) & block == 1
egen block1extreme_total = total(`block1extreme'), by(prolific_id)

** Gen variable if at least one decision matches that condition
gen block1_ever_extreme = (block1extreme_total > 0)

** Block 2
tempvar block2extreme
gen `block2extreme' = ((payment == 2 & WTP == 4.125) | (payment == 4 & WTP == -4.125)) & block == 2
egen block2extreme_total = total(`block2extreme'), by(prolific_id)

** Gen variable if at least one decision matches that condition
gen block2_ever_extreme = (block2extreme_total > 0)

drop extreme_total block1extreme_total block2extreme_total

preserve
keep prolific_id ever_extreme
duplicates drop prolific_id, force

** Save this
save `"$preppeddata/Experiment 3/ever_extreme_indicator.dta"', replace
restore


** #2 Eliminate people who ever decrease their WTP for the easy version
** #3 Eliminate people who decrease their WTP with higher incentives two or more times.

** Get behavior for each of the 4 $1 increases
bysort prolific_id block (payment): gen numeric_block_change = WTP[_n] - WTP[_n-1]
gen WTP_change_behavior = "Increased" if numeric_block_change > 0 
replace WTP_change_behavior = "Decreased" if numeric_block_change < 0 
replace WTP_change_behavior = "Same" if numeric_block_change == 0 
drop if numeric_block_change == .

** Gen new variable if they decreased
gen decrease = (WTP_change_behavior == "Decreased")
egen decrease_total = total(decrease), by(prolific_id)

** Gen indicators for ever decreasing and decreasing two or more times
gen ever_decrease = (decrease_total > 0)
gen decrease2ormore = (decrease_total >= 2)

** Keep relevant variables — we'll merge this data to keep our desired indicators
keep prolific_id block1_ever_extreme block2_ever_extreme ever_extreme ever_decrease decrease2ormore
duplicates drop prolific_id, force

** Save this
save `"$preppeddata/Experiment 3/sample_restricted_indicators.dta"', replace
